---
url: https://www.normattiva.it/uri-res/N2Ls?urn:nir:stato:decreto.legislativo:2016-08-26;179
url_xml: https://www.normattiva.it/do/atto/caricaAKN?dataGU=20160913&codiceRedaz=16G00192&dataVigenza=20251104
dataGU: 20160913
codiceRedaz: 16G00192
dataVigenza: 20251104
---

# Modifiche ed integrazioni al Codice dell'amministrazione digitale, di cui al decreto legislativo 7 marzo 2005, n. 82, ai sensi dell'articolo 1 della legge 7 agosto 2015, n. 124, in materia di riorganizzazione delle amministrazioni pubbliche. (16G00192)

IL PRESIDENTE DELLA REPUBBLICA

Visti gli articoli 76, 87 e 117, secondo comma, lettera r), della Costituzione;

Visto l'articolo 1 della legge 7 agosto 2015, n. 124, recante deleghe al Governo in materia di riorganizzazione delle amministrazioni pubbliche;

Visto il regolamento (UE) 23 luglio 2014, n. 910, del Parlamento europeo e del Consiglio in materia di identificazione elettronica e servizi fiduciari per le transazioni elettroniche nel mercato interno e che abroga la direttiva 1999/93/CE;

Vista la legge 7 agosto 1990, n. 241, recante nuove norme in materia di procedimento amministrativo e di diritto di accesso ai documenti amministrativi;

Visto il decreto legislativo 12 febbraio 1993, n. 39, recante norme in materia di sistemi informativi automatizzati delle amministrazioni pubbliche, a norma dell'articolo 2, comma 1, lettera mm), della legge 23 ottobre 1992, n. 421;

Visto il decreto legislativo 30 luglio 1999, n. 300, recante disciplina dell'attivita' di Governo e ordinamento della Presidenza del Consiglio dei ministri;

Visto il decreto legislativo 30 marzo 2001, n. 165, recante norme generali sull'ordinamento del lavoro alle dipendenze delle amministrazioni pubbliche;

Visto il decreto legislativo 30 giugno 2003, n. 196, recante codice in materia di protezione dei dati personali;

Vista la legge 9 gennaio 2004, n. 4, recante disposizioni per favorire l'accesso dei soggetti disabili agli strumenti informatici;

Visto il decreto legislativo 7 marzo 2005, n. 82, recante Codice dell'amministrazione digitale;

Visto l'articolo 1, comma 368, lettera d), della legge 23 dicembre 2005, n. 266;

Visto l'articolo 3 del decreto legislativo 1° dicembre 2009, n. 177;

Visti gli articoli 19 e 20 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134;

Visto il testo unico delle disposizioni legislative e regolamentari in materia di documentazione amministrativa (Testo A), di cui al decreto del Presidente della Repubblica 28 dicembre 2000, n. 445;

Vista la preliminare deliberazione del Consiglio dei ministri, adottata nella riunione del 20 gennaio 2016;

Sentito il Garante per la protezione dei dati personali;

Acquisito il parere della Conferenza unificata, ai sensi dell'articolo 8, del decreto legislativo 28 agosto 1997, n. 281, espresso nella seduta del 3 marzo 2016;

Udito il parere del Consiglio di Stato, espresso dalla Sezione consultiva per gli atti normativi nell'Adunanza dell'11 maggio 2016;

Acquisito il parere della Commissione parlamentare per la semplificazione e delle Commissioni parlamentari competenti per materia e per i profili finanziari;

Vista la deliberazione del Consiglio dei ministri, adottata nella riunione del 10 agosto 2016;

Su proposta del Ministro per la semplificazione e la pubblica amministrazione;

Emana il seguente decreto legislativo:

## Art. 1. - Modifiche all'articolo 1 del decreto legislativo n. 82 del 2005

1. All'articolo 1, comma 1, del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) prima della lettera a), e' inserita la seguente: «0a) AgID: l'Agenzia per l'Italia digitale di cui all'articolo 19 del decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134;»;
- b) dopo la lettera i-quinquies) e' inserita la seguente: «i-sexies) dati territoriali: i dati che attengono, direttamente o indirettamente, a una localita' o a un'area geografica specifica;»;
- c) dopo la lettera n-bis) e' inserita la seguente: «n-ter) domicilio digitale: l'indirizzo di posta elettronica certificata o altro servizio elettronico di recapito certificato qualificato di cui al Regolamento (UE) 23 luglio 2014 n. 910 del Parlamento europeo e del Consiglio in materia di identificazione elettronica e servizi fiduciari per le transazioni elettroniche nel mercato interno e che abroga la direttiva 1999/93/CE, di seguito «Regolamento eIDAS», che consenta la prova del momento di ricezione di una comunicazione tra i soggetti di cui all'articolo 2, comma 2, e i soggetti giuridici, che sia basato su standard o norme riconosciute nell'ambito dell'unione europea;»;
- d) la lettera p) e' sostituita dalla seguente: «p) documento informatico: il documento elettronico che contiene la rappresentazione informatica di atti, fatti o dati giuridicamente rilevanti;»;
- e) alla lettera s) le parole: «elettronica avanzata» sono sostituite dalla seguente: «qualificata» e le parole: «certificato qualificato e» sono soppresse;
- f) dopo la lettera u-ter) e' inserita la seguente: «u-quater) identita' digitale: la rappresentazione informatica della corrispondenza tra un utente e i suoi attributi identificativi, verificata attraverso l'insieme dei dati raccolti e registrati in forma digitale secondo le modalita' fissate nel decreto attuativo dell'articolo 64;»;
- g) dopo la lettera bb) sono inserite le seguenti: «cc) titolare del dato: uno dei soggetti di cui all'articolo 2, comma 2, che ha originariamente formato per uso proprio o commissionato ad altro soggetto il documento che rappresenta il dato, o che ne ha la disponibilita'; dd) interoperabilita': caratteristica di un sistema informativo, le cui interfacce sono pubbliche e aperte, di interagire in maniera automatica con altri sistemi informativi per lo scambio di informazioni e l'erogazione di servizi; ee) cooperazione applicativa: la parte del Sistema Pubblico di Connettivita' finalizzata all'interazione tra i sistemi informatici dei soggetti partecipanti, per garantire l'integrazione dei metadati, delle informazioni, dei processi e procedimenti amministrativi.»;
- h) le lettere a), b), e), f), g), h), i), l), m), n), o), q), q-bis), r), t), u), u-ter), z) e bb) sono soppresse.

2. Dopo il comma 1 sono aggiunti i seguenti: «1-bis. Ai fini del presente Codice, valgono le definizioni di cui all'articolo 3 del Regolamento eIDAS; 1-ter. Ove la legge consente l'utilizzo della posta elettronica certificata e' ammesso anche l'utilizzo di altro servizio elettronico di recapito certificato.».

## Art. 2. - Modifiche all'articolo 2 del decreto legislativo n. 82 del 2005

1. All'articolo 2 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 dopo le parole: «modalita' piu' appropriate» sono inserite le seguenti: «e nel modo piu' adeguato al soddisfacimento degli interessi degli utenti»;
- b) il comma 2 e' sostituito dal seguente: «2. Le disposizioni del presente Codice si applicano alle pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo 30 marzo 2001, n. 165, nel rispetto del riparto di competenza di cui all'articolo 117 della Costituzione, nonche' alle societa' a controllo pubblico, come definite nel decreto legislativo adottato in attuazione dell'articolo 18 della legge n. 124 del 2015, escluse le societa' quotate come definite dallo stesso decreto legislativo adottato in attuazione dell'articolo 18 della legge n. 124 del 2015.»;
- c) i commi 5 e 6 sono sostituiti dai seguenti: «5. Le disposizioni del presente Codice si applicano nel rispetto della disciplina in materia di trattamento dei dati personali e, in particolare, delle disposizioni del Codice in materia di protezione dei dati personali approvato con decreto legislativo 30 giugno 2003, n. 196; 6. Le disposizioni del presente Codice non si applicano limitatamente all'esercizio delle attivita' e funzioni ispettive e di controllo fiscale, di ordine e sicurezza pubblica, difesa e sicurezza nazionale, polizia giudiziaria e polizia economico-finanziaria e consultazioni elettorali. Le disposizioni del presente Codice si applicano altresi' al processo civile, penale, amministrativo, contabile e tributario, in quanto compatibili e salvo che non sia diversamente disposto dalle disposizioni in materia di processo telematico.».

## Art. 3. - Modifiche all'articolo 3 del decreto legislativo n. 82 del 2005

1. All'articolo 3 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Chiunque ha il diritto di usare le soluzioni e gli strumenti di cui al presente Codice nei rapporti con i soggetti di cui all'articolo 2, comma 2, anche ai fini della partecipazione al procedimento amministrativo, fermi restando i diritti delle minoranze linguistiche riconosciute.»;
- b) dopo il comma 1-ter sono aggiunti i seguenti: «1-quater. La gestione dei procedimenti amministrativi e' attuata dai soggetti di cui all'articolo 2, comma 2, in modo da consentire, mediante strumenti informatici, la possibilita' per il cittadino di verificare anche con mezzi telematici i termini previsti ed effettivi per lo specifico procedimento e il relativo stato di avanzamento, nonche' di individuare l'ufficio e il funzionario responsabile del procedimento; 1-quinquies. Tutti i cittadini e le imprese hanno il diritto all'assegnazione di un'identita' digitale attraverso la quale accedere e utilizzare i servizi erogati in rete dai soggetti di cui all'articolo 2, comma 2, alle condizioni di cui all'articolo 64; 1-sexies. Tutti gli iscritti all'Anagrafe nazionale della popolazione residente (ANPR) hanno il diritto di essere identificati dalle pubbliche amministrazioni tramite l'identita' digitale di cui al comma 1-quinquies, nonche' di inviare comunicazioni e documenti alle pubbliche amministrazioni e di riceverne dalle stesse tramite un domicilio digitale, alle condizioni di cui all'articolo 3-bis.».

## Art. 4. - Modifiche all'articolo 3-bis del decreto legislativo n. 82 del 2005

1. All'articolo 3-bis del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Domicilio digitale delle persone fisiche»;
- b) il comma 1 e' sostituito dal seguente: «1. Al fine di facilitare la comunicazione tra pubbliche amministrazioni e cittadini, e' facolta' di ogni cittadino indicare al comune di residenza un proprio domicilio digitale.»;
- c) al comma 2, le parole: «L'indirizzo» sono sostituite dalle seguenti: «Il domicilio» e, in fine, e' aggiunto il seguente periodo: «Esso inerisce esclusivamente alle comunicazioni e alle notifiche e costituisce mezzo esclusivo di comunicazione e notifica da parte dei soggetti di cui all'articolo 2, comma 2.»;
- d) il comma 3 e' abrogato;
- e) dopo il comma 3 e' inserito il seguente: «3-bis. Agli iscritti all'ANPR che non abbiano provveduto a indicarne uno e' messo a disposizione un domicilio digitale con modalita' stabilite con decreto del Ministro dell'interno di concerto con il Ministro delegato per la semplificazione e la pubblica amministrazione, sentito il Garante per la protezione dei dati personali. Con lo stesso decreto sono individuate altre modalita' con le quali, per superare il divario digitale, i documenti possono essere consegnati ai cittadini.»;
- f) al comma 4-bis, le parole: «di cui al comma 1,» sono sostituite dalle seguenti: «di cui ai commi 1 e 2» e, dopo le parole: «firma elettronica» sono inserite le seguenti: «qualificata o»;
- g) al comma 4-quater, le parole: «all'articolo 23-ter, comma 5,» sono sostituite dalle seguenti: «all'articolo 23, comma 2-bis,»;
- h) dopo il comma 4-quater e' inserito il seguente: «4-quinquies. Il domicilio speciale di cui all'articolo 47 del Codice civile puo' essere eletto anche presso un domicilio digitale diverso da quello di cui al comma 1. Qualora l'indirizzo digitale indicato quale domicilio speciale non rientri tra quelli indicati all'articolo 1, comma 1-ter, colui che lo ha eletto non puo' opporre eccezioni relative a tali circostanze.».

## Art. 5. - Modifiche all'articolo 5 del decreto legislativo n. 82 del 2005

1. All'articolo 5 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. I soggetti di cui all'articolo 2, comma 2, sono obbligati ad accettare, tramite la piattaforma di cui al comma 2, i pagamenti spettanti a qualsiasi titolo attraverso sistemi di pagamento elettronico, ivi inclusi, per i micro-pagamenti, quelli basati sull'uso del credito telefonico. Resta ferma la possibilita' di accettare anche altre forme di pagamento elettronico, senza discriminazione in relazione allo schema di pagamento abilitato per ciascuna tipologia di strumento di pagamento elettronico come definita ai sensi dell'articolo 2, punti 33), 34) e 35) del regolamento UE 2015/751 del Parlamento europeo e del Consiglio del 29 aprile 2015 relativo alle commissioni interbancarie sulle operazioni di pagamento basate su carta.»;
- b) il comma 2 e' sostituito dal seguente: «2. Al fine di dare attuazione al comma 1, l'AgID mette a disposizione, attraverso il Sistema pubblico di connettivita', una piattaforma tecnologica per l'interconnessione e l'interoperabilita' tra le pubbliche amministrazioni e i prestatori di servizi di pagamento abilitati, al fine di assicurare, attraverso gli strumenti di cui all'articolo 64, l'autenticazione dei soggetti interessati all'operazione in tutta la gestione del processo di pagamento.»;
- c) dopo il comma 2 e' inserito il seguente: «2-bis. Ai sensi dell'articolo 71, e sentita la Banca d'Italia, sono determinate le modalita' di attuazione del comma 1, inclusi gli obblighi di pubblicazione di dati e le informazioni strumentali all'utilizzo degli strumenti di pagamento di cui al medesimo comma.»;
- d) i commi 3, 3-bis e 3-ter sono abrogati;
- e) al comma 4 le parole: «, lettere a) e b)» sono soppresse.

## Art. 6. - Modifiche all'articolo 6 del decreto legislativo n. 82 del 2005

1. All'articolo 6, comma 1, del decreto legislativo n. 82 del 2005, le parole: «Per le comunicazioni» sono sostituite dalle seguenti: «Fino alla piena attuazione delle disposizioni di cui all'articolo 3-bis, per le comunicazioni».

## Art. 7. - Modifiche all'articolo 6-bis del decreto legislativo n. 82 del 2005

1. All'articolo 6-bis, del decreto legislativo n. 82 del 2005, sono apportate le seguenti modificazioni:

- a) al comma 2 e' aggiunto in fine il seguente periodo: «Gli indirizzi PEC inseriti in tale Indice costituiscono mezzo esclusivo di comunicazione e notifica con i soggetti di cui all'articolo 2, comma 2.»;
- b) dopo il comma 2 e' inserito il seguente: «2-bis. L'INI-PEC acquisisce dagli ordini e dai collegi professionali gli attributi qualificati dell'identita' digitale ai fini di quanto previsto dal decreto di cui all'articolo 64, comma 2-sexies.».

2. Dopo l'articolo 6-bis e' inserito il seguente: «Art. 6-ter. (Indice degli indirizzi delle pubbliche amministrazioni e dei gestori di pubblici servizi). - 1. Al fine di assicurare la pubblicita' dei riferimenti telematici delle pubbliche amministrazioni e dei gestori dei pubblici servizi e' istituito il pubblico elenco di fiducia denominato "Indice degli indirizzi della pubblica amministrazione e dei gestori di pubblici servizi", nel quale sono indicati gli indirizzi di posta elettronica certificata da utilizzare per le comunicazioni e per lo scambio di informazioni e per l'invio di documenti a tutti gli effetti di legge tra le pubbliche amministrazioni, i gestori di pubblici servizi e i privati. 2. La realizzazione e la gestione dell'Indice sono affidate all'AgID, che puo' utilizzare a tal fine elenchi e repertori gia' formati dalle amministrazioni pubbliche. 3. Le amministrazioni di cui al comma 1 aggiornano gli indirizzi e i contenuti dell'Indice tempestivamente e comunque con cadenza almeno semestrale, secondo le indicazioni dell'AgID. La mancata comunicazione degli elementi necessari al completamento dell'Indice e del loro aggiornamento e' valutata ai fini della responsabilita' dirigenziale e dell'attribuzione della retribuzione di risultato ai dirigenti responsabili.».

## Art. 8. - Modifiche all'articolo 7 del decreto legislativo n. 82 del 2005

1. L'articolo 7 del decreto legislativo n. 82 del 2005 e' sostituito dal seguente: «Art. 7. (Qualita' dei servizi resi e soddisfazione dell'utenza). - 1. I soggetti di cui all'articolo 2, comma 2, provvedono alla riorganizzazione e all'aggiornamento dei servizi resi, sulla base di una preventiva analisi delle reali esigenze dei soggetti giuridici e rendono disponibili i propri servizi per via telematica nel rispetto delle disposizioni del presente Codice e degli standard e livelli di qualita' anche in termini di fruibilita', accessibilita', usabilita' e tempestivita', stabiliti con le regole tecniche di cui all'articolo 71. 2. Gli standard e i livelli di qualita' sono periodicamente aggiornati dall'AgID tenuto conto dell'evoluzione tecnologica e degli standard di mercato e resi noti attraverso pubblicazione in un'apposita area del sito web istituzionale della medesima Agenzia. 3. Per i servizi in rete, i soggetti di cui all'articolo 2, comma 2, consentono agli utenti di esprimere la soddisfazione rispetto alla qualita', anche in termini di fruibilita', accessibilita' e tempestivita', del servizio reso all'utente stesso e pubblicano sui propri siti i dati risultanti, ivi incluse le statistiche di utilizzo. 4. In caso di violazione degli obblighi di cui al presente articolo, gli interessati possono agire in giudizio, anche nei termini e con le modalita' stabilite nel decreto legislativo 20 dicembre 2009, n. 198.».

## Art. 9. - Modifiche all'articolo 8 del decreto legislativo n. 82 del 2005

1. Il comma 1 dell'articolo 8 del decreto legislativo n. 82 del 2005 e' sostituito dal seguente: «Lo Stato e i soggetti di cui all'articolo 2, comma 2, promuovono iniziative volte a favorire la diffusione della cultura digitale tra i cittadini con particolare riguardo ai minori e alle categorie a rischio di esclusione, anche al fine di favorire lo sviluppo di competenze di informatica giuridica e l'utilizzo dei servizi digitali delle pubbliche amministrazioni con azioni specifiche e concrete, avvalendosi di un insieme di mezzi diversi fra i quali il servizio radiotelevisivo.».

2. Dopo l'articolo 8 e' inserito il seguente: «Art. 8-bis. (Connettivita' alla rete Internet negli uffici e luoghi pubblici). - 1. I soggetti di cui all'articolo 2, comma 2, favoriscono, in linea con gli obiettivi dell'Agenda digitale europea, la disponibilita' di connettivita' alla rete Internet presso gli uffici pubblici e altri luoghi pubblici, in particolare nei settori scolastico, sanitario e di interesse turistico, anche prevedendo che la porzione di banda non utilizzata dagli stessi uffici sia messa a disposizione degli utenti attraverso un sistema di autenticazione tramite SPID, carta d'identita' elettronica o carta nazionale dei servizi, ovvero che rispetti gli standard di sicurezza fissati dall'Agid. 2. I soggetti di cui all'articolo 2, comma 2, mettono a disposizione degli utenti connettivita' a banda larga per l'accesso alla rete Internet nei limiti della banda disponibile e con le modalita' determinate dall'AgID.».

## Art. 10. - Modifiche all'articolo 9 del decreto legislativo n. 82 del 2005

1. Al comma 1 dell'articolo 9 del decreto legislativo n. 82 del 2005, le parole: «Le pubbliche amministrazioni» sono sostituite dalle seguenti: «I soggetti di cui all'articolo 2, comma 2,», e le parole: «sia individuali che collettivi» sono sostituite dalle seguenti: «e migliorare la qualita' dei propri atti, anche attraverso l'utilizzo, ove previsto e nell'ambito delle risorse disponibili a legislazione vigente, di forme di consultazione preventiva per via telematica sugli schemi di atto da adottare».

## Art. 11. - Modifiche all'articolo 12 del decreto legislativo n. 82 del 2005

1. All'articolo 12 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 le parole da: «la garanzia dei diritti» fino alla fine del periodo sono sostituite dalle seguenti: «l'effettivo riconoscimento dei diritti dei cittadini e delle imprese di cui al presente Codice in conformita' agli obiettivi indicati nel Piano triennale per l'informatica nella pubblica amministrazione di cui all'articolo 14-bis, comma 2, lettera b).»;
- b) il comma 2 e' sostituito dal seguente: «2. Le pubbliche amministrazioni utilizzano, nei rapporti interni, in quelli con altre amministrazioni e con i privati, le tecnologie dell'informazione e della comunicazione, garantendo l'interoperabilita' dei sistemi e l'integrazione dei processi di servizio fra le diverse amministrazioni nel rispetto delle regole tecniche di cui all'articolo 71.»;
- c) dopo il comma 3 e' inserito il seguente: «3-bis. I soggetti di cui all'articolo 2, comma 2, favoriscono l'uso da parte dei lavoratori di dispositivi elettronici personali o, se di proprieta' dei predetti soggetti, personalizzabili, al fine di ottimizzare la prestazione lavorativa, nel rispetto delle condizioni di sicurezza nell'utilizzo.»;
- d) i commi 4, 5 e 5-bis sono abrogati.

2. Le disposizioni di cui al comma 1, lettera b), si applicano con riferimento ai nuovi sistemi informativi delle pubbliche amministrazioni.

## Art. 12. - Modifiche all'articolo 13 del decreto legislativo n. 82 del 2005

1. All'articolo 13 del decreto legislativo n. 82 del 2005 dopo il comma 1 e' aggiunto il seguente: «1-bis. Le politiche di formazione di cui al comma 1 sono altresi' volte allo sviluppo delle competenze tecnologiche, di informatica giuridica e manageriali dei dirigenti, per la transizione alla modalita' operativa digitale.».

## Art. 13. - Modifiche all'articolo 14 del decreto legislativo n. 82 del 2005

1. All'articolo 14 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 2 e' aggiunto, in fine, il seguente periodo: «L'AgID assicura il coordinamento informatico dell'amministrazione statale, regionale e locale, con la finalita' di progettare e monitorare l'evoluzione strategica del sistema informativo della pubblica amministrazione, favorendo l'adozione di infrastrutture e standard che riducano i costi sostenuti dalle amministrazioni e migliorino i servizi erogati.»;
- b) al comma 2-ter sono aggiunte, in fine, le seguenti parole: «, secondo le modalita' di cui al comma 2»;
- c) i commi 3 e 3-bis sono abrogati.

2. Dopo l'articolo 14 del decreto legislativo n. 82 del 2005 e' inserito il seguente: «14-bis. (Agenzia per l'Italia digitale). - 1. L'Agenzia per l'Italia Digitale (AgID) e' preposta alla realizzazione degli obiettivi dell'Agenda Digitale Italiana, in coerenza con gli indirizzi dettati dal Presidente del Consiglio dei ministri o dal Ministro delegato, e con l'Agenda digitale europea. AgID, in particolare, promuove l'innovazione digitale nel Paese e l'utilizzo delle tecnologie digitali nell'organizzazione della pubblica amministrazione e nel rapporto tra questa, i cittadini e le imprese, nel rispetto dei principi di legalita', imparzialita' e trasparenza e secondo criteri di efficienza, economicita' ed efficacia. Essa presta la propria collaborazione alle istituzioni dell'Unione europea e svolge i compiti necessari per l'adempimento degli obblighi internazionali assunti dallo Stato nelle materie di competenza. 2. AgID svolge le funzioni di: a) emanazione di regole, standard e guide tecniche, nonche' di vigilanza e controllo sul rispetto delle norme di cui al presente Codice, anche attraverso l'adozione di atti amministrativi generali, in materia di agenda digitale, digitalizzazione della pubblica amministrazione, sicurezza informatica, interoperabilita' e cooperazione applicativa tra sistemi informatici pubblici e quelli dell'Unione europea; b) programmazione e coordinamento delle attivita' delle amministrazioni per l'uso delle tecnologie dell'informazione e della comunicazione, mediante la redazione e la successiva verifica dell'attuazione del Piano triennale per l'informatica nella pubblica amministrazione contenente la fissazione degli obiettivi e l'individuazione dei principali interventi di sviluppo e gestione dei sistemi informativi delle amministrazioni pubbliche. Il predetto Piano e' elaborato dall'AgID, anche sulla base dei dati e delle informazioni acquisiti dalle pubbliche amministrazioni di cui all'articolo 1, comma 2, del decreto legislativo n. 165 del 2001, ed e' approvato dal Presidente del Consiglio dei ministri o dal Ministro delegato entro il 30 settembre di ogni anno; c) monitoraggio delle attivita' svolte dalle amministrazioni in relazione alla loro coerenza con il Piano triennale di cui alla lettera b) e verifica dei risultati conseguiti dalle singole amministrazioni con particolare riferimento ai costi e benefici dei sistemi informatici secondo le modalita' fissate dalla stessa Agenzia; d) predisposizione, realizzazione e gestione di interventi e progetti di innovazione, anche realizzando e gestendo direttamente o avvalendosi di soggetti terzi, specifici progetti in tema di innovazione ad essa assegnati nonche' svolgendo attivita' di progettazione e coordinamento delle iniziative strategiche e di preminente interesse nazionale, anche a carattere intersettoriale; e) promozione della cultura digitale e della ricerca anche tramite comunita' digitali regionali; f) rilascio di pareri tecnici, obbligatori e non vincolanti, sugli schemi di contratti e accordi quadro da parte delle pubbliche amministrazioni centrali concernenti l'acquisizione di beni e servizi relativi a sistemi informativi automatizzati per quanto riguarda la congruita' tecnico-economica, qualora il valore lordo di detti contratti sia superiore a euro 1.000.000,00 nel caso di procedura negoziata e a euro 2.000.000,00 nel caso di procedura ristretta o di procedura aperta. Il parere e' reso tenendo conto dei principi di efficacia, economicita', ottimizzazione della spesa delle pubbliche amministrazioni e favorendo l'adozione di infrastrutture condivise e standard che riducano i costi sostenuti dalle singole amministrazioni e il miglioramento dei servizi erogati, nonche' in coerenza con i principi, i criteri e le indicazioni contenuti nei piani triennali approvati. Il parere e' reso entro il termine di quarantacinque giorni dal ricevimento della relativa richiesta. Si applicano gli articoli 16 e 17-bis della legge 7 agosto 1990, n. 241, e successive modificazioni. Copia dei pareri tecnici attinenti a questioni di competenza dell'Autorita' nazionale anticorruzione e' trasmessa dall'AgID a detta Autorita'; g) rilascio di pareri tecnici, obbligatori e non vincolanti, sugli elementi essenziali delle procedure di gara bandite, ai sensi dell'articolo 1, comma 512 della legge 28 dicembre 2015, n. 208, da Consip e dai soggetti aggregatori di cui all'articolo 9 del decreto-legge 24 aprile 2014, n. 66, concernenti l'acquisizione di beni e servizi relativi a sistemi informativi automatizzati e definiti di carattere strategico nel piano triennale. Ai fini della presente lettera per elementi essenziali si intendono l'oggetto della fornitura o del servizio, il valore economico del contratto, la tipologia di procedura che si intende adottare, il criterio di aggiudicazione e relativa ponderazione, le principali clausole che caratterizzano le prestazioni contrattuali. Si applica quanto previsto nei periodi da 2 a 5 della lettera f); h) definizione di criteri e modalita' per il monitoraggio sull'esecuzione dei contratti da parte dell'amministrazione interessata ovvero, su sua richiesta, da parte della stessa AgID; i) vigilanza sui servizi fiduciari ai sensi dell'articolo 17 del regolamento UE 910/2014 in qualita' di organismo a tal fine designato, sui gestori di posta elettronica certificata, sui soggetti di cui all'articolo 44-bis, nonche' sui soggetti, pubblici e privati, che partecipano a SPID di cui all'articolo 64; nell'esercizio di tale funzione l'Agenzia puo' irrogare per le violazioni accertate a carico dei soggetti vigilati le sanzioni amministrative di cui all'articolo 32-bis in relazione alla gravita' della violazione accertata e all'entita' del danno provocato all'utenza; l) ogni altra funzione attribuitale da specifiche disposizioni di legge e dallo Statuto. 3. Fermo restando quanto previsto al comma 2, AgID svolge ogni altra funzione prevista da leggi e regolamenti gia' attribuita a DigitPA, all'Agenzia per la diffusione delle tecnologie per l'innovazione nonche' al Dipartimento per l'innovazione tecnologica della Presidenza del Consiglio dei ministri.».

## Art. 14. - Modifiche all'articolo 16 del decreto legislativo n. 82 del 2005

1. All'articolo 16, comma 1, lettera e), del decreto legislativo n. 82 del 2005 le parole: «detta norme tecniche ai sensi dell'articolo 71 e» sono soppresse.

## Art. 15. - Modifiche all'articolo 17 del decreto legislativo n. 82 del 2005

1. All'articolo 17 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1, alinea, e' sostituito dal seguente: «1. Le pubbliche amministrazioni garantiscono l'attuazione delle linee strategiche per la riorganizzazione e la digitalizzazione dell'amministrazione definite dal Governo in coerenza con le regole tecniche di cui all'articolo 71. A tal fine, ciascuno dei predetti soggetti affida a un unico ufficio dirigenziale generale, fermo restando il numero complessivo di tali uffici, la transizione alla modalita' operativa digitale e i conseguenti processi di riorganizzazione finalizzati alla realizzazione di un'amministrazione digitale e aperta, di servizi facilmente utilizzabili e di qualita', attraverso una maggiore efficienza ed economicita'. Al suddetto ufficio sono inoltre attribuiti i compiti relativi a:»;
- b) al comma 1, lettera e), dopo la parola: «analisi» e' inserita la seguente: «periodica»;
- c) al comma 1, lettera j), dopo le parole «firma digitale» sono inserite le seguenti: «o firma elettronica qualificata»;
- d) il comma 1-ter e' sostituito dal seguente: «1-ter. Il responsabile dell'ufficio di cui al comma 1 e' dotato di adeguate competenze tecnologiche, di informatica giuridica e manageriali e risponde, con riferimento ai compiti relativi alla transizione, alla modalita' digitale direttamente all'organo di vertice politico.»;
- e) dopo il comma 1-ter sono aggiunti i seguenti: «1-quater. Le pubbliche amministrazioni, fermo restando il numero complessivo degli uffici, individuano, di norma tra i dirigenti di ruolo in servizio, un difensore civico per il digitale in possesso di adeguati requisiti di terzieta', autonomia e imparzialita'. Al difensore civico per il digitale chiunque puo' inviare segnalazioni e reclami relativi ad ogni presunta violazione del presente Codice e di ogni altra norma in materia di digitalizzazione ed innovazione della pubblica amministrazione. Se tali segnalazioni sono fondate, il difensore civico per il digitale invita l'ufficio responsabile della presunta violazione a porvi rimedio tempestivamente e comunque nel termine di trenta giorni. Il difensore segnala le inadempienze all'ufficio competente per i procedimenti disciplinari. 1-quinquies. AgID pubblica sul proprio sito una guida di riepilogo dei diritti di cittadinanza digitali previsti dal presente Codice. 1-sexies. Nel rispetto della propria autonomia organizzativa, le pubbliche amministrazioni diverse dalle amministrazioni dello Stato individuano l'ufficio per il digitale di cui ai commi 1 e 1-quater tra quelli di livello dirigenziale oppure, ove ne siano privi, individuano un responsabile per il digitale tra le proprie posizioni apicali. In assenza del vertice politico, il responsabile dell'ufficio per il digitale di cui al comma 1 risponde direttamente a quello amministrativo dell'ente.».

## Art. 16. - Modifiche all'articolo 18 del decreto legislativo n. 82 del 2005

1. All'articolo 18 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) i commi da 1 a 3 sono sostituiti dai seguenti: «1. E' istituita presso la Presidenza del Consiglio dei ministri la Conferenza permanente per l'innovazione tecnologica, con il compito di supportare il Presidente del Consiglio o il Ministro delegato nell'elaborazione delle linee strategiche di indirizzo in materia di innovazione e digitalizzazione. 2. La Conferenza e' nominata con decreto del Presidente del Consiglio dei ministri e composta da quattro esperti in materia di innovazione e digitalizzazione, di cui uno con funzione di Presidente e uno designato dalle regioni, e dal Direttore generale dell'AgID. 3. La Conferenza opera anche attraverso la consultazione telematica di rappresentanti di ministeri ed enti pubblici e dei portatori di interessi, i quali costituiscono la Consulta permanente dell'innovazione, che opera come sistema aperto di partecipazione.»;
- b) dopo il comma 3 e' aggiunto il seguente: «3-bis. Alla Consulta permanente dell'innovazione possono essere sottoposte proposte di norme e di atti amministrativi suscettibili di incidere sulle materie disciplinate dal presente codice.»;
- c) i commi 4 e 5 sono abrogati.

## Art. 17. - Modifiche all'articolo 20 del decreto legislativo n. 82 del 2005

1. All'articolo 20 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Validita' ed efficacia probatoria dei documenti informatici»;
- b) il comma 1 e' abrogato;
- c) il comma 1-bis e' sostituito dal seguente: «1-bis. L'idoneita' del documento informatico a soddisfare il requisito della forma scritta e il suo valore probatorio sono liberamente valutabili in giudizio, in relazione alle sue caratteristiche oggettive di qualita', sicurezza, integrita' e immodificabilita'.»;
- d) al comma 3 le parole: «temporale» e: «avanzata» sono soppresse.

## Art. 18. - Modifiche all'articolo 21 del decreto legislativo n. 82 del 2005

1. All'articolo 21 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1, dopo le parole «firma elettronica,» sono inserite le seguenti parole: «soddisfa il requisito della forma scritta e»;
- b) il comma 2 e' sostituito dal seguente: «2. Il documento informatico sottoscritto con firma elettronica avanzata, qualificata o digitale, formato nel rispetto delle regole tecniche di cui all'articolo 20, comma 3, ha altresi' l'efficacia prevista dall'articolo 2702 del codice civile. L'utilizzo del dispositivo di firma elettronica qualificata o digitale si presume riconducibile al titolare, salvo che questi dia prova contraria. Restano ferme le disposizioni concernenti il deposito degli atti e dei documenti in via telematica secondo la normativa anche regolamentare in materia di processo telematico.»;
- c) al comma 2-bis, le parole: «Salvo quanto previsto dall'articolo 25» sono sostituite dalle seguenti: «Salvo il caso di sottoscrizione autenticata» e le parole: «soddisfano comunque il requisito della forma scritta se sottoscritti con firma elettronica avanzata, qualificata o digitale.» sono sostituite dalle seguenti: «redatti su documento informatico o formati attraverso procedimenti informatici sono sottoscritti, a pena di nullita', con firma elettronica avanzata, qualificata o digitale.»;
- d) dopo il comma 2-bis e' inserito il seguente: «2-ter. Fatto salvo quanto previsto dal decreto legislativo 2 luglio 2010, n. 110, ogni altro atto pubblico redatto su documento informatico e' sottoscritto dal pubblico ufficiale a pena di nullita' con firma qualificata o digitale. Le parti, i fidefacenti, l'interprete e i testimoni sottoscrivono personalmente l'atto, in presenza del pubblico ufficiale, con firma avanzata, qualificata o digitale ovvero con firma autografa acquisita digitalmente e allegata agli atti.»;
- e) i commi 3 e 4 sono abrogati.

## Art. 19. - Modifiche all'articolo 22 del decreto legislativo n. 82 del 2005

1. All'articolo 22 del decreto legislativo n. 82 del 2005 il comma 6 e' abrogato.

## Art. 20. - Modifiche all'articolo 23 del decreto legislativo n. 82 del 2005

1. All'articolo 23 del decreto legislativo n. 82 del 2005, dopo il comma 2 e' aggiunto il seguente: «2-bis. Sulle copie analogiche di documenti informatici puo' essere apposto a stampa un contrassegno, sulla base dei criteri definiti con le regole tecniche di cui all'articolo 71, tramite il quale e' possibile accedere al documento informatico, ovvero verificare la corrispondenza allo stesso della copia analogica. Il contrassegno apposto ai sensi del primo periodo sostituisce a tutti gli effetti di legge la sottoscrizione autografa del pubblico ufficiale e non puo' essere richiesta la produzione di altra copia analogica con sottoscrizione autografa del medesimo documento informatico. I programmi software eventualmente necessari alla verifica sono di libera e gratuita disponibilita'.».

## Art. 21. - Modifiche all'articolo 23-ter del decreto legislativo n. 82 del 2005

1. All'articolo 23-ter del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 4 e' sostituito dal seguente: «4. Le regole tecniche in materia di formazione e conservazione di documenti informatici delle pubbliche amministrazioni sono definite ai sensi dell'articolo 71, di concerto con il Ministro dei beni e delle attivita' culturali e del turismo.»;
- b) i commi 2 e 5 sono abrogati.

## Art. 22. - Modifiche all'articolo 24 del decreto legislativo n. 82 del 2005

1. All'articolo 24 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 4 le parole: «stabilite ai sensi dell'articolo 71» sono sostituite dalle seguenti: «di cui all'articolo 71»;
- b) dopo il comma 4 sono aggiunti, in fine, i seguenti commi: «4-bis. L'apposizione a un documento informatico di una firma digitale o di un altro tipo di firma elettronica qualificata basata su un certificato elettronico revocato, scaduto o sospeso equivale a mancata sottoscrizione, salvo che lo stato di sospensione sia stato annullato. La revoca o la sospensione, comunque motivate, hanno effetto dal momento della pubblicazione, salvo che il revocante, o chi richiede la sospensione, non dimostri che essa era gia' a conoscenza di tutte le parti interessate. 4-ter. Le disposizioni del presente articolo si applicano anche se la firma elettronica e' basata su un certificato qualificato rilasciato da un certificatore stabilito in uno Stato non facente parte dell'Unione europea, quando ricorre una delle seguenti condizioni: a) il certificatore possiede i requisiti previsti dal regolamento eIDAS ed e' qualificato in uno Stato membro; b) il certificato qualificato e' garantito da un certificatore stabilito nella Unione europea, in possesso dei requisiti di cui al medesimo regolamento; c) il certificato qualificato, o il certificatore, e' riconosciuto in forza di un accordo bilaterale o multilaterale tra l'Unione europea e Paesi terzi o organizzazioni internazionali.».

## Art. 23. - Modifiche all'articolo 25 del decreto legislativo n. 82 del 2005

1. All'articolo 25 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 dopo le parole: «tipo di firma» e' inserita la seguente: «elettronica»;
- b) al comma 4 le parole: ", comma 5" sono soppresse.

## Art. 24. - Modifiche all'articolo 28 del decreto legislativo n. 82 del 2005

1. All'articolo 28 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Certificati di firma elettronica qualificata»;
- b) il comma 1 e' abrogato;
- c) il comma 2 e' sostituito dal seguente: «2. In aggiunta alle informazioni previste nel Regolamento eIDAS, fatta salva la possibilita' di utilizzare uno pseudonimo, nel certificato di firma elettronica qualificata puo' essere inserito il codice fiscale. Per i titolari residenti all'estero cui non risulti attribuito il codice fiscale, si puo' indicare il codice fiscale rilasciato dall'autorita' fiscale del Paese di residenza o, in mancanza, un analogo codice identificativo univoco, quale ad esempio un codice di sicurezza sociale o un codice identificativo generale.»;
- d) al comma 3, alinea, le parole: «certificato qualificato» sono sostituite dalle seguenti: «certificato di firma elettronica qualificata» e dopo le parole «se pertinenti» sono aggiunte le seguenti: «e non eccedenti rispetto»;

## Art. 25. - Modifiche all'articolo 29 del decreto legislativo n. 82 del 2005

1. All'articolo 29 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Qualificazione e accreditamento»;
- b) il comma 1 e' sostituito dal seguente: «1. I soggetti che intendono avviare la prestazione di servizi fiduciari qualificati o svolgere l'attivita' di gestore di posta elettronica certificata, di gestore dell'identita' digitale di cui all'articolo 64, di conservatore di documenti informatici di cui all'articolo 44-bis presentano all'AgID domanda, rispettivamente, di qualificazione o di accreditamento, allegando alla stessa una relazione di valutazione della conformita' rilasciata da un organismo di valutazione della conformita' accreditato dall'organo designato ai sensi del Regolamento CE 765/2008 del Parlamento europeo e del Consiglio del 9 luglio 2008 e dell'articolo 4, comma 2, della legge 23 luglio 2009, n. 99.»;
- c) il comma 2 e' sostituito dal seguente: «2. Il richiedente deve trovarsi nelle condizioni previste dall'articolo 24 del Regolamento eIDAS»;
- d) il comma 3 e' sostituito dal seguente: «3. Fatto salvo quanto previsto dall'articolo 44-bis, comma 3, del presente decreto e dall'articolo 14, comma 3, del decreto del Presidente della Repubblica 11 febbraio 2005, n. 68, il richiedente deve inoltre possedere i requisiti individuati con decreto del Presidente del Consiglio dei ministri da fissare in base ai seguenti criteri: a) per quanto riguarda il capitale sociale, graduazione entro il limite massimo di cinque milioni di euro, in proporzione al livello di servizio offerto; b) per quanto riguarda le garanzie assicurative, graduazione in modo da assicurarne l'adeguatezza in proporzione al livello di servizio offerto.»;
- e) al comma 4 la parola: «accreditamento» e' sostituita dalle seguenti: «qualificazione o di accreditamento»;
- f) al comma 6 dopo la parola: «elenco» sono inserite le seguenti: «di fiducia»;
- g) i commi 7 e 8 sono abrogati.

## Art. 26. - Modifiche all'articolo 30 del decreto legislativo n. 82 del 2005

1. All'articolo 30 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Responsabilita' dei prestatori di servizi fiduciari qualificati, dei gestori di posta elettronica certificata, dei gestori dell'identita' digitale e di conservatori»;
- b) il comma 1 e' sostituito dal seguente: «1. I prestatori di servizi fiduciari qualificati, i gestori di posta elettronica certificata, i gestori dell'identita' digitale di cui all'articolo 64 e i soggetti di cui all'articolo 44-bis che cagionano danno ad altri nello svolgimento della loro attivita', sono tenuti al risarcimento, se non provano di avere adottato tutte le misure idonee a evitare il danno.»;
- c) il comma 2 e' abrogato.

## Art. 27. - Modifiche all'articolo 32 del decreto legislativo n. 82 del 2005

1. All'articolo 32 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Obblighi del titolare e del prestatore di servizi di firma elettronica qualificata»;
- b) al comma 1, dopo le parole: «custodia del dispositivo di firma», sono inserite le seguenti: «o degli strumenti di autenticazione informatica per l'utilizzo del dispositivo di firma da remoto,»;
- c) la parola: «certificatore» e' sostituita, ovunque ricorra, dalle seguenti: «prestatore di servizi di firma elettronica qualificata»;
- d) al comma 3, alinea, la parola: «inoltre» e' sostituita dalla seguente: «comunque»;
- e) al comma 3, lettera g), dopo le parole: «compromissione del dispositivo di firma», sono inserite le seguenti: «o degli strumenti di autenticazione informatica per l'utilizzo del dispositivo di firma,»;
- f) al comma 5, le parole: «raccoglie i dati personali solo direttamente dalla persona cui si riferiscono o previo suo esplicito consenso,» sono sostituite dalle seguenti: «raccoglie i dati personali direttamente dalla persona cui si riferiscono o, previo suo esplicito consenso, tramite il terzo,».

## Art. 28. - Modifiche all'articolo 32-bis del decreto legislativo n. 82 del 2005

1. All'articolo 32-bis del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Sanzioni per i prestatori di servizi fiduciari qualificati, per i gestori di posta elettronica certificata, per i gestori dell'identita' digitale e per i conservatori»;
- b) il comma 1 e' sostituito dal seguente: «1. L'AgID puo' irrogare ai prestatori di servizi fiduciari qualificati, ai gestori di posta elettronica certificata, ai gestori dell'identita' digitale e, limitatamente alle attivita' di conservazione di firme, sigilli o certificati elettronici, ai soggetti di cui all'articolo 44-bis, che abbiano violato gli obblighi del Regolamento eIDAS e o del presente Codice, sanzioni amministrative in relazione alla gravita' della violazione accertata e all'entita' del danno provocato all'utenza, per importi da un minimo di euro 4.000,00 a un massimo di euro 40.000,00, fermo restando il diritto al risarcimento del maggior danno. Nei casi di particolare gravita' l'AgID puo' disporre la cancellazione del soggetto dall'elenco dei soggetti qualificati. Le sanzioni vengono irrogate dal direttore generale dell'AgID, sentito il Comitato di indirizzo. Si applica, in quanto compatibile, la disciplina della legge 24 novembre 1981, n. 689.»;
- c) dopo il comma 1 e' inserito il seguente: «1-bis. L'AgID, prima di irrogare la sanzione amministrativa di cui al comma 1, diffida i soggetti a conformare la propria condotta agli obblighi previsti dal Regolamento eIDAS o dal presente Codice, fissando un termine e disciplinando le relative modalita' per adempiere.»;
- d) al comma 2, le parole: «nel sistema» sono sostituite dalle seguenti: «nei sistemi di posta elettronica certificata» e le parole: «il certificatore qualificato o» sono soppresse;
- e) al comma 3 dopo le parole «commi 1» inserire le seguenti: «, 1-bis;»;
- f) il comma 4 e' abrogato.

## Art. 29. - Modifiche all'articolo 34 del decreto legislativo n. 82 del 2005

1. All'articolo 34 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Norme particolari per le pubbliche amministrazioni»;
- b) al comma 1, lettera a) la parola: «accreditarsi» e' sostituita dalla seguente: «qualificarsi» e l'ultimo periodo e' soppresso.
- c) i commi 3, 4 e 5 sono abrogati.

## Art. 30. - Modifiche all'articolo 35 del decreto legislativo n. 82 del 2005

1. All'articolo 35 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Dispositivi sicuri e procedure per la generazione della firma qualificata»;
- b) dopo il comma 1 e' inserito il seguente: «1-bis) Fermo restando quanto previsto dal comma 1, i dispositivi per la creazione di una firma elettronica qualificata o di un sigillo elettronico soddisfano i requisiti di cui all'Allegato II del Regolamento eIDAS.»;
- c) al comma 5, primo periodo, dopo le parole «di una firma» e' inserita la seguente: «elettronica», dopo la parola «qualificata» sono inserite le seguenti: «o di un sigillo elettronico» e, infine, le parole: «dall'Allegato III della direttiva 1999/93/CE» sono sostituite dalle seguenti: «dall'Allegato II del regolamento eIDAS»;
- d) il comma 6 e' sostituito dal seguente: «6. La conformita' di cui al comma 5 e' inoltre riconosciuta se accertata da un organismo all'uopo designato da un altro Stato membro e notificato ai sensi dell'articolo 30, comma 2, del Regolamento eIDAS. Ove previsto dall'organismo di cui al periodo precedente, la valutazione della conformita' del sistema e degli strumenti di autenticazione utilizzati dal titolare delle chiavi di firma e' effettuata dall'AgID in conformita' alle linee guida di cui al comma 5.».

## Art. 31. - Modifiche all'articolo 37 del decreto legislativo n. 82 del 2005

1. All'articolo 37 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1, le parole: «Il certificatore qualificato o accreditato» sono sostituite dalle seguenti: «Il prestatore di servizi fiduciari qualificato»;
- b) al comma 2, primo periodo, la parola: «certificatore» e' sostituita dalla seguente «prestatore» e, al secondo periodo, la parola: «certificatore» e' sostituita dalle seguenti: «prestatore di servizi fiduciari qualificato»;
- c) al comma 3 la parola: «certificatore» e' sostituita dalla seguente: «prestatore»;
- d) al comma 4 le parole «certificatore accreditato» sono sostituite dalle seguenti: «prestatore di cui al comma 1»;
- e) al comma 4-bis, le parole: «certificatore qualificato» sono sostituite dalle seguenti: «prestatore di cui al comma 1» e le parole: «un certificatore» sono sostituite dalle seguenti: «un prestatore di servizi fiduciari qualificato»;
- f) dopo il comma 4-bis e' aggiunto, infine, il seguente: «4-ter. Nel caso in cui il prestatore di cui al comma 1 non ottemperi agli obblighi previsti dal presente articolo, AgID intima al prestatore di ottemperarvi entro un termine non superiore a trenta giorni. In caso di mancata ottemperanza entro il suddetto termine, si applicano le sanzioni di cui all'articolo 32-bis; le sanzioni pecuniarie previste dal predetto articolo sono aumentate fino al doppio.».

## Art. 32. - Modifiche all'articolo 40 del decreto legislativo n. 82 del 2005

1. All'articolo 40 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 dopo le parole: «propri documenti» sono inserite le seguenti: «, inclusi quelli inerenti ad albi, elenchi e pubblici registri,»;
- b) i commi 3 e 4 sono abrogati.

## Art. 33. - Modifiche all'articolo 40-bis del decreto legislativo n. 82 del 2005

1. All'articolo 40-bis del decreto legislativo n. 82 del 2005 le parole: «47, commi 1 e 3, 54, comma 2-ter, 57-bis, comma 1» sono sostituite dalle seguenti: «6-ter, comma 1, 47, commi 1 e 3,».

## Art. 34. - Modifiche all'articolo 41 del decreto legislativo n. 82 del 2005

1. All'articolo 41 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Le pubbliche amministrazioni gestiscono i procedimenti amministrativi utilizzando le tecnologie dell'informazione e della comunicazione. Per ciascun procedimento amministrativo di loro competenza, esse forniscono gli opportuni servizi di interoperabilita' e cooperazione applicativa, ai sensi di quanto previsto dall'articolo 12, comma 2.»;
- b) al comma 2-bis le parole: «, di concerto con il Ministro della funzione pubblica» sono soppresse;
- c) i commi 1-bis e 3 sono abrogati.

## Art. 35. - Modifiche all'articolo 43 del decreto legislativo n. 82 del 2005

1. All'articolo 43 del decreto legislativo n. 82 del 2005, dopo il comma 1 e' inserito il seguente: «1-bis. Se il documento informatico e' conservato per legge da uno dei soggetti di cui all'articolo 2, comma 2, cessa l'obbligo di conservazione a carico dei cittadini e delle imprese che possono in ogni momento richiedere accesso al documento stesso.».

## Art. 36. - Modifiche all'articolo 44 del decreto legislativo n. 82 del 2005

1. All'articolo 44 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Requisiti per la gestione e conservazione dei documenti informatici»;
- b) il comma 1 e' sostituito dal seguente: «1. Il sistema di gestione informatica e conservazione dei documenti informatici della pubblica amministrazione assicura: a) l'identificazione certa del soggetto che ha formato il documento e dell'amministrazione o dell'area organizzativa omogenea di riferimento di cui all'articolo 50, comma 4, del decreto del Presidente della Repubblica 28 dicembre 2000, n. 445; b) la sicurezza e l'integrita' del sistema e dei dati e documenti presenti; c) la corretta e puntuale registrazione di protocollo dei documenti in entrata e in uscita; d) la raccolta di informazioni sul collegamento esistente tra ciascun documento ricevuto dall'amministrazione e i documenti dalla stessa formati; e) l'agevole reperimento delle informazioni riguardanti i documenti registrati; f) l'accesso, in condizioni di sicurezza, alle informazioni del sistema, nel rispetto delle disposizioni in materia di tutela dei dati personali; g) lo scambio di informazioni, ai sensi di quanto previsto dall'articolo 12, comma 2, con sistemi di gestione documentale di altre amministrazioni al fine di determinare lo stato e l'iter dei procedimenti complessi; h) la corretta organizzazione dei documenti nell'ambito del sistema di classificazione adottato; i) l'accesso remoto, in condizioni di sicurezza, ai documenti e alle relative informazioni di registrazione tramite un identificativo univoco; j) il rispetto delle regole tecniche di cui all'articolo 71.»;
- c) il comma 1-bis e' sostituito dal seguente: «1-bis. Il sistema di gestione e conservazione dei documenti informatici e' gestito da un responsabile che opera d'intesa con il dirigente dell'ufficio di cui all'articolo 17 del presente Codice, il responsabile del trattamento dei dati personali di cui all'articolo 29 del decreto legislativo 30 giugno 2003, n. 196, ove nominato, e con il responsabile del sistema della conservazione dei documenti informatici, nella definizione e gestione delle attivita' di rispettiva competenza. Almeno una volta all'anno il responsabile della gestione dei documenti informatici provvede a trasmettere al sistema di conservazione i fascicoli e le serie documentarie anche relative a procedimenti conclusi.»;
- d) al comma 1-ter le parole: «dall'articolo 43 e dalle regole tecniche ivi previste, nonche' dal comma 1» sono sostituite dalle seguenti: «nel presente articolo».

## Art. 37. - Modifiche all'articolo 44-bis del decreto legislativo n. 82 del 2005

1. All'articolo 44-bis del decreto legislativo n. 82 del 2005, al comma 1 sono aggiunte, in fine, le seguenti parole: «secondo le regole tecniche di cui all'articolo 71».

## Art. 38. - Modifiche all'articolo 47 del decreto legislativo n. 82 del 2005

1. All'articolo 47 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Trasmissione dei documenti tra le pubbliche amministrazioni»;
- b) al comma 1 aggiungere, in fine, il seguente periodo: «Il documento puo' essere, altresi', reso disponibile previa comunicazione delle modalita' di accesso telematico allo stesso.».

## Art. 39. - Modifiche all'articolo 48 del decreto legislativo n. 82 del 2005

2. All'articolo 48 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 le parole: «con decreto del Presidente del Consiglio dei Ministri, sentito DigitPA» sono sostituite dalle seguenti: «con le regole tecniche adottate ai sensi dell'articolo 71»;
- b) al comma 3 le parole: «al decreto del Presidente del Consiglio dei Ministri di cui al comma 1» sono sostituite dalle seguenti: «alle regole tecniche adottate ai sensi dell'articolo 71».

## Art. 40. - Modifiche all'articolo 50 del decreto legislativo n. 82 del 2005

1. All'articolo 50 del decreto legislativo n. 82 del 2005 dopo il comma 3 e' aggiunto, infine, il seguente: «3-bis. Il trasferimento di un dato da un sistema informativo a un altro non modifica la titolarita' del dato.».

## Art. 41. - Modifiche all'articolo 51 del decreto legislativo n. 82 del 2005

1. All'articolo 51 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1, le parole «le modalita' che garantiscono l'esattezza,» sono sostituite dalle seguenti: «le soluzioni tecniche idonee a garantire la protezione,» e le parole «dei dati,» sono sostituite dalle seguenti: «dei dati e la continuita' operativa»;
- b) il comma 1-bis, alinea, e' sostituito dal seguente: «1-bis. AgID attua, per quanto di competenza e in raccordo con le altre autorita' competenti in materia, il Quadro strategico nazionale per la sicurezza dello spazio cibernetico e il Piano nazionale per la sicurezza cibernetica e la sicurezza informatica. AgID, in tale ambito»:
- c) la lettera a) del comma 1-bis e' sostituita dalla seguente: «a) coordina, tramite il Computer Emergency Response Team Pubblica Amministrazione (CERT-PA) istituito nel suo ambito, le iniziative di prevenzione e gestione degli incidenti di sicurezza informatici;»;
- d) il comma 2-bis e' abrogato.

## Art. 42. - Modifiche all'articolo 52 del decreto legislativo n. 82 del 2005

1. All'articolo 52 del decreto legislativo n. 82 del 2005 i commi 1 e 8 sono abrogati.

## Art. 43. - Modifiche all'articolo 53 del decreto legislativo n. 82 del 2005

1. All'articolo 53 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Siti Internet delle pubbliche amministrazioni»;
- b) al comma 1, primo periodo, la parola: «centrali» e' soppressa;
- c) dopo il comma 1 sono inseriti i seguenti: «1-bis. Le pubbliche amministrazioni pubblicano, ai sensi dell'articolo 9 del decreto legislativo 14 marzo 2013, n. 33, anche il catalogo dei dati e dei metadati definitivi, nonche' delle relative banche dati in loro possesso e i regolamenti che disciplinano l'esercizio della facolta' di accesso telematico e il riutilizzo di tali dati e metadati, fatti salvi i dati presenti in Anagrafe tributaria. 1-ter. Con le regole tecniche di cui all'articolo 71 sono definite le modalita' per la realizzazione e la modifica dei siti delle amministrazioni.»;
- d) i commi 2 e 3 sono abrogati.

## Art. 44. - Modifiche all'articolo 54 del decreto legislativo n. 82 del 2005

1. All'articolo 54 del decreto legislativo n. 82 del 2005 il comma 1 e' sostituito dal seguente: «1. I siti delle pubbliche amministrazioni contengono i dati di cui al decreto legislativo 14 marzo 2013, n. 33, e successive modificazioni, recante il riordino della disciplina riguardante gli obblighi di pubblicita', trasparenza e diffusione di informazioni da parte delle pubbliche amministrazioni.».

## Art. 45. - Modifiche all'articolo 59 del decreto legislativo n. 82 del 2005

1. All'articolo 59 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) i commi 1 e 2 sono abrogati;
- b) il comma 3 e' sostituito dal seguente: «3. Per agevolare la pubblicita' dei dati di interesse generale, disponibili presso le pubbliche amministrazioni a livello nazionale, regionale e locale, presso l'AgID e' istituito il Repertorio nazionale dei dati territoriali, quale infrastruttura di riferimento per l'erogazione dei servizi di ricerca dei dati territoriali, e relativi servizi, e punto di accesso nazionale ai fini dell'attuazione della direttiva 2007/2/CE (direttiva INSPIRE) per quanto riguarda i metadati.»;
- c) il comma 4 e' abrogato;
- d) il comma 5 e' sostituito dal seguente: «5. Con decreto adottato ai sensi dell'articolo 71 sono adottate, anche su proposta delle amministrazioni competenti, le regole tecniche per la definizione e l'aggiornamento del contenuto del Repertorio nazionale dei dati territoriali di cui al comma 3 nonche' per la formazione, la documentazione, lo scambio e il riutilizzo dei dati territoriali detenuti dalle amministrazioni stesse.»;
- e) i commi 6 e 7-bis sono abrogati.

## Art. 46. - Modifiche all'articolo 60 del decreto legislativo n. 82 del 2005

1. All'articolo 60 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1, le parole da: «utilizzabile» a: «vigenti» sono sostituite dalle seguenti: «rilevante per lo svolgimento delle funzioni istituzionali delle altre pubbliche amministrazioni, anche solo per fini statistici, nel rispetto delle competenze e delle normative vigenti e possiedono i requisiti di cui al comma 2»;
- b) al comma 2, secondo periodo, le parole da: «La realizzazione» a: «di cui all'articolo 73» sono sostituite dalle seguenti: «Tali sistemi informativi possiedono le caratteristiche minime di sicurezza, accessibilita' e interoperabilita' e sono realizzati e aggiornati secondo le regole tecniche di cui all'articolo 71»;
- c) il comma 3 e' abrogato;
- d) al comma 3-bis, alinea, le parole: «e fino all'adozione del decreto di cui al comma 3» sono soppresse;
- e) dopo il comma 3-bis e' inserito il seguente: «3-ter. L'AgID pubblica sul proprio sito istituzionale l'elenco delle basi di dati di interesse nazionale realizzate ai sensi del presente articolo.».

## Art. 47. - Modifiche all'articolo 61 del decreto legislativo n. 82 del 2005

1. Al comma 1 dell'articolo 61 del decreto legislativo n. 82 del 2005, le parole: «Fermo restando il termine di cui all'articolo 40, comma 4,» sono soppresse.

## Art. 48. - Modifiche all'articolo 62 del decreto legislativo n. 82 del 2005

1. All'articolo 62 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 le parole: «l'Anagrafe nazionale della popolazione residente (ANPR)» sono sostituite dalle seguenti: «l'ANPR»;
- b) al comma 3 le parole: «dell'Anagrafe nazionale» sono sostituite dalle seguenti: «dell'Anagrafe stessa»;
- c) al comma 6, lettera a), la parola: «58» e' sostituita dalla seguente: «50».

## Art. 49. - Modifiche all'articolo 63 del decreto legislativo n. 82 del 2005

1. All'articolo 63 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 le parole: «Le pubbliche amministrazioni centrali» sono sostituite dalle seguenti: «I soggetti di cui all'articolo 2, comma 2,»;
- b) al comma 2, primo periodo, le parole: «Le pubbliche amministrazioni e i gestori di servizi pubblici» sono sostituite dalle seguenti: «I soggetti di cui all'articolo 2, comma 2,»;
- c) al comma 2, secondo periodo, le parole: «in conformita' alle regole tecniche da emanare ai sensi dell'articolo 71. Per le amministrazioni e i gestori di servizi pubblici regionali e locali le regole tecniche sono adottate previo parere della Commissione permanente per l'innovazione tecnologica nelle regioni e negli enti locali di cui all'articolo 14, comma 3-bis.» sono sostituite dalle seguenti: «in conformita' alle regole tecniche di cui all'articolo 71.»;
- d) i commi 3-bis, 3-ter, 3-quater e 3-quinquies sono abrogati.

## Art. 50. - Modifiche all'articolo 64 del decreto legislativo n. 82 del 2005

1. All'articolo 64 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) la rubrica e' sostituita dalla seguente: «Sistema pubblico per la gestione delle identita' digitali e modalita' di accesso ai servizi erogati in rete dalle pubbliche amministrazioni»;
- b) i commi 1 e 2 sono abrogati;
- c) il comma 2-ter e' sostituito dal seguente: «2-ter. Il sistema SPID e' costituito come insieme aperto di soggetti pubblici e privati che, previo accreditamento da parte dell'AgID, secondo modalita' definite con il decreto di cui al comma 2-sexies, identificano gli utenti per consentire loro l'accesso ai servizi in rete.»;
- d) al comma 2-sexies, lettera c), le parole: «, compresi gli strumenti di cui al comma 1» sono soppresse;
- e) dopo il comma 2-sexies sono aggiunti i seguenti: «2-septies. Un atto giuridico puo' essere posto in essere da un soggetto identificato mediante SPID, nell'ambito di un sistema informatico avente i requisiti fissati nelle regole tecniche adottate ai sensi dell'articolo 71, attraverso processi idonei a garantire, in maniera manifesta e inequivoca, l'acquisizione della sua volonta'. Restano ferme le disposizioni concernenti il deposito degli atti e dei documenti in via telematica secondo la normativa anche regolamentare in materia di processo telematico. 2-octies. Le pubbliche amministrazioni consentono mediante SPID l'accesso ai servizi in rete da esse erogati che richiedono identificazione informatica. 2-nonies. L'accesso di cui al comma 2-octies puo' avvenire anche con la carta di identita' elettronica e la carta nazionale dei servizi.».

2. Dopo l'articolo 64 e' inserito il seguente: «Art. 64-bis. (Accesso telematico ai servizi della Pubblica Amministrazione). - 1. I soggetti di cui all'articolo 2, comma 2, rendono fruibili i propri servizi in rete, in conformita' alle regole tecniche di cui all'articolo 71, tramite il punto unico di accesso telematico attivato presso la Presidenza del Consiglio dei ministri, senza nuovi o maggiori oneri per la finanza pubblica.».

## Art. 51. - Modifiche all'articolo 65 del decreto legislativo n. 82 del 2005

1. All'articolo 65 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1, lettera a), la parola: «accreditato» e' sostituita dalla seguente: «qualificato»;
- b) al comma 1, lettera b), le parole da «l'autore» fino alla fine del periodo sono sostituite dalle seguenti: «l'istante o il dichiarante e' identificato attraverso il sistema pubblico di identita' digitale (SPID), nonche' attraverso uno degli altri strumenti di cui all'articolo 64, comma 2-novies, nei limiti ivi previsti;»;
- c) al comma 1, la lettera c), e' sostituita dalla seguente: «c) ovvero sono sottoscritte e presentate unitamente alla copia del documento d'identita';»;
- d) al comma 1, lettera c-bis, le parole «dall'autore» sono sostituite dalle seguenti: «dall'istante o dal dichiarante»;
- e) il comma 1-bis e' abrogato;
- f) al comma 1-ter le parole: «, lettere a), c) e c-bis),» sono soppresse;
- g) al comma 2 le parole: «inviate o compilate sul sito secondo le modalita' previste dal comma 1» sono sostituite dalle seguenti: «di cui al comma 1».

## Art. 52. - (Modifiche all'articolo 66 del decreto legislativo n. 82 del 2005)

1. All'articolo 66 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 8, dopo le parole: «modalita' elettroniche» sono inserite le seguenti: «, nel rispetto delle regole tecniche di cui all'articolo 71,»;
- b) il comma 8-bis e' abrogato.

## Art. 53. - Modifiche all'articolo 68 del decreto legislativo n. 82 del 2005

1. All'articolo 68 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1-ter, le parole: "dall'Agenzia per l'Italia digitale, che, a richiesta di soggetti interessati, esprime altresi' parere circa il loro rispetto" sono sostituite dalle seguenti: "dall'AgID";
- b) i commi 2, 2-bis e 4 sono abrogati.

## Art. 54. - (Modifiche all'articolo 69 del decreto legislativo n. 82 del 2005

L'articolo 69 del decreto legislativo n. 82 del 2005 e' sostituito dal seguente: «Art. 69 (Riuso delle soluzioni e standard aperti). - 1. Le pubbliche amministrazioni che siano titolari di soluzioni e programmi informatici realizzati su specifiche indicazioni del committente pubblico, hanno l'obbligo di rendere disponibile il relativo codice sorgente, completo della documentazione e rilasciato in repertorio pubblico sotto licenza aperta, in uso gratuito ad altre pubbliche amministrazioni o ai soggetti giuridici che intendano adattarli alle proprie esigenze, salvo motivate ragioni di ordine e sicurezza pubblica, difesa nazionale e consultazioni elettorali. 2. Al fine di favorire il riuso dei programmi informatici di proprieta' delle pubbliche amministrazioni, ai sensi del comma 1, nei capitolati o nelle specifiche di progetto e' previsto, ove possibile, che i programmi ed i servizi ICT appositamente sviluppati per conto e a spese dell'amministrazione siano conformi alle specifiche tecniche di SPC definite da AgID.».

## Art. 55. - Modifiche all'articolo 70 del decreto legislativo n. 82 del 2005

1. All'articolo 70 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. AgID definisce i requisiti minimi affinche' i programmi informatici realizzati dalle pubbliche amministrazioni siano idonei al riuso da parte di altre pubbliche amministrazioni, anche con riferimento a singoli moduli. Sono altresi' definite le modalita' di inserimento nella banca dati dei programmi informatici riutilizzabili gestita da AgID.»;
- b) il comma 2 e' abrogato.

## Art. 56. - Modifiche all'articolo 71 del decreto legislativo n. 82 del 2005

1. All'articolo 71 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) il comma 1 e' sostituito dal seguente: «1. Con decreto del Ministro delegato per la semplificazione e la pubblica amministrazione, su proposta dell'AgID, di concerto con il Ministro della giustizia e con i Ministri competenti, sentita la Conferenza unificata di cui all'articolo 8 del decreto legislativo 28 agosto 1997, n. 281, e il Garante per la protezione dei dati personali nelle materie di competenza, sono adottate le regole tecniche per l'attuazione del presente Codice.»;
- b) il comma 2 e' abrogato.

## Art. 57. - Modifiche all'articolo 73 del decreto legislativo n. 82 del 2005

1. All'articolo 73 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) al comma 1 le parole da: «(SPC),» fino alla fine del periodo sono sostituite dalle seguenti: «e cooperazione (SPC), quale insieme di infrastrutture tecnologiche e di regole tecniche che assicura l'interoperabilita' tra i sistemi informativi delle pubbliche amministrazioni, permette il coordinamento informativo e informatico dei dati tra le amministrazioni centrali, regionali e locali e tra queste e i sistemi dell'Unione europea ed e' aperto all'adesione da parte dei gestori di servizi pubblici e dei soggetti privati.»;
- b) il comma 2 e' sostituito dal seguente: «2. Il SPC garantisce la sicurezza e la riservatezza delle informazioni, nonche' la salvaguardia e l'autonomia del patrimonio informativo di ciascun soggetto aderente.»;
- c) al comma 3, la lettera a) e' sostituita dalla seguente: «a) sviluppo architetturale e organizzativo atto a garantire la federabilita' dei sistemi;»;
- d) al comma 3, dopo la lettera b), e' inserita la seguente: «b-bis) aggiornamento continuo del sistema e aderenza alle migliori pratiche internazionali;»;
- e) il comma 3-bis e' abrogato;
- f) dopo il comma 3-bis sono aggiunti i seguenti: «3-ter. Il SPC e' costituito da un insieme di elementi che comprendono: a) infrastrutture, architetture e interfacce tecnologiche; b) linee guida e regole per la cooperazione e l'interoperabilita'; c) catalogo di servizi e applicazioni. 3-quater. Ai sensi dell'articolo 71 sono dettate le regole tecniche del Sistema pubblico di connettivita' e cooperazione, al fine di assicurarne: l'aggiornamento rispetto alla evoluzione della tecnologia; l'aderenza alle linee guida europee in materia di interoperabilita'; l'adeguatezza rispetto alle esigenze delle pubbliche amministrazioni e dei suoi utenti; la piu' efficace e semplice adozione da parte di tutti i soggetti, pubblici e privati, il rispetto di necessari livelli di sicurezza.».

## Art. 58. - Modifiche all'articolo 75 del decreto legislativo n. 82 del 2005

1. All'articolo 75 del decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) i commi 1, 2 e 3 sono sostituiti dai seguenti: «1. I soggetti di cui all'articolo 2, comma 2, partecipano al SPC, salve le esclusioni collegate all'esercizio delle funzioni di ordine e sicurezza pubblica, difesa nazionale, consultazioni elettorali. 2. Chiunque puo' partecipare al SPC nel rispetto delle regole tecniche di cui all'articolo 73, comma 3-quater. 3. AgID rende gratuitamente disponibili specifiche delle interfacce tecnologiche, le linee guida, le regole di cooperazione e ogni altra informazione necessaria a garantire l'interoperabilita' del SPC con ogni soluzione informatica sviluppata autonomamente da privati o da altre amministrazioni che rispettano le regole definite ai sensi dell'articolo 73, comma 3-quater.»;
- b) il comma 3-bis e' abrogato.

## Art. 59. - Modifiche all'articolo 76 del decreto legislativo n. 82 del 2005

1. All'articolo 76, comma 1, del decreto legislativo n. 82 del 2005 le parole: «tra le pubbliche amministrazioni» sono soppresse.

2. Dopo l'articolo 76 del decreto legislativo n. 82 del 2005 e' inserito il seguente: «Art. 76-bis (Costi del SPC). - 1. I costi relativi alle infrastrutture nazionali per l'interoperabilita' sono a carico dei fornitori, per i servizi da essi direttamente utilizzati e proporzionalmente agli importi dei relativi contratti di fornitura e una quota di tali costi e' a carico delle pubbliche amministrazioni relativamente ai servizi da esse utilizzati. L'eventuale parte del contributo di cui all'articolo 18, comma 3, del decreto legislativo 1° dicembre 2009, n. 177, che eccede la copertura dei costi diretti e indiretti, comprensivi di rimborsi per eventuali attivita' specificamente richieste dalla Consip ad AgID in relazione alle singole procedure, sostenuti dalla stessa Consip per le attivita' di centrale di committenza di cui all'articolo 4, comma 3-quater, del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, e' destinata a parziale copertura della quota dei costi relativi alle infrastrutture nazionali gestite da AgID.».

## Art. 60. - Incentivi e sanzioni. Portale della performance

1. Con il decreto legislativo adottato ai sensi dell'articolo 17 della legge 7 agosto 2015, n. 124, sono disciplinati gli incentivi relativi all'attuazione delle disposizioni del decreto legislativo n. 82 del 2005, il suo rilievo ai fini della valutazione dei risultati, nonche' la rilevanza, ai fini della responsabilita' dirigenziale, della violazione delle medesime disposizioni e del mancato o inadeguato utilizzo delle tecnologie ivi disciplinate.

2. Entro 6 mesi dall'entrata in vigore del presente decreto l'Agid stabilisce le modalita' per la realizzazione, nell'ambito delle risorse disponibili a legislazione vigente, di una banca dati degli obiettivi e degli indicatori delle performance di cui al decreto legislativo 27 ottobre 2009, n. 150, nell'ambito del Portale della performance, gia' Portale della trasparenza, di cui all'articolo 19, comma 9, del decreto-legge 24 giugno 2014, n. 90. A far data dall'effettiva costituzione della suddetta banca dati, gli obblighi di pubblicazione e comunicazione tra amministrazioni sono assolti con la trasmissione al Portale della performance, secondo le modalita' stabilite dall'AgID. Il decreto legislativo da adottare ai sensi dell'articolo 17 della legge n. 124 del 2015 disciplina il rilievo della mancata trasmissione ai fini della responsabilita' dirigenziale.

## Art. 61. - Disposizioni di coordinamento

1. ((PERIODO SOPPRESSO DAL D.LGS. 13 DICEMBRE 2017, N. 217)). ((PERIODO SOPPRESSO DAL D.LGS. 13 DICEMBRE 2017, N. 217)). Fino all'adozione ((delle Linee guida di cui all'articolo 71 del decreto legislativo n. 82 del 2005)), l'obbligo per le amministrazioni pubbliche di adeguare i propri sistemi di gestione informatica dei documenti, di cui all'articolo 17 del decreto del Presidente del Consiglio dei ministri 13 novembre 2014, e' sospeso, salva la facolta' per le amministrazioni medesime di adeguarsi anteriormente. Fino all'adozione del decreto del Presidente del Consiglio dei ministri di cui all'articolo 29, comma 3, del decreto legislativo n. 82 del 2005, come modificato dall'articolo 25 del presente decreto, restano efficaci le disposizioni dell'articolo 29, comma 3, dello stesso decreto nella formulazione previgente all'entrata in vigore del presente decreto.

2. Al decreto legislativo n. 82 del 2005 sono apportate le seguenti modificazioni:

- a) le parole: «presente decreto», ovunque ricorrano, sono sostituite dalle seguenti: «presente Codice»;
- b) la parola: «DigitPA», ovunque ricorra, e' sostituita dalla seguente: «AgID»;
- c) la rubrica del Capo VIII e' sostituita dalla seguente: «Sistema pubblico di connettivita'» e la ripartizione in sezioni dello stesso Capo e' abrogata;
- d) la parola «cittadino», ovunque ricorra, si intende come «persona fisica» e le espressioni «chiunque» e «cittadini e imprese», ovunque ricorrano, si intendono come «soggetti giuridici».

3. All'articolo 30-ter del decreto legislativo 13 agosto 2010, n. 141, sono apportate le seguenti modificazioni:

- a) al comma 1, e' aggiunto, in fine, il seguente periodo: «Tale sistema puo' essere utilizzato anche per svolgere funzioni di supporto al controllo delle identita' e alla prevenzione del furto di identita' in settori diversi da quelli precedentemente indicati, limitatamente al riscontro delle informazioni strettamente pertinenti.»;
- b) al comma 5, dopo la lettera b) e' inserita la seguente: «b-bis) i soggetti di cui all'articolo 29 del decreto legislativo 7 marzo 2005, n. 82;».

4. All'articolo 28, comma 3, lettera c), del decreto legislativo 21 novembre 2007, n. 231, sono aggiunte, in fine, le seguenti parole: «ovvero siano dotati di identita' digitale di livello massimo di sicurezza nell'ambito del Sistema di cui all'articolo 64 del predetto decreto legislativo n. 82 del 2005».

5. All'articolo 33-septies del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, dopo il comma 4-bis e' inserito il seguente: «4-ter. La societa' di cui all'articolo 83, comma 15, del decreto-legge 25 giugno 2008, n. 112, convertito, con modificazioni, dalla legge 6 agosto 2008, n. 133, realizza uno dei poli strategici per l'attuazione e la conduzione dei progetti e la gestione dei dati, delle applicazioni e delle infrastrutture delle amministrazioni centrali di interesse nazionale previsti dal piano triennale di cui al comma 4.».

6. All'articolo 4, comma 3-quater del decreto-legge 6 luglio 2012, n. 95, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 135, le parole: «previsto dall'articolo 20 del decreto-legge 22 giugno 2012, n. 83» sono sostituite dalle seguenti: «previsto dall'articolo 14-bis del decreto legislativo 7 marzo 2005, n. 82»; le parole «dell'articolo 83» e le parole «all'articolo 86» sono soppresse.

7. Le disposizioni di cui al presente decreto legislativo non si applicano alle procedure e ai contratti i cui relativi bandi o avvisi di gara siano stati pubblicati prima dell'entrata in vigore del presente decreto.

8. All'articolo 21 del testo unico delle disposizioni legislative in materia di tutela e sostegno della maternita' e della paternita', di cui al decreto legislativo 26 marzo 2001, n. 151, sono apportate le seguenti modificazioni:

- a) al comma 1-bis) le parole «A decorrere dal termine indicato nel comma 2-ter, il» sono sostituite dalla seguente: «Il» e le parole da «secondo» fino alla fine del comma sono sostituite dalle seguenti: «secondo le modalita' e utilizzando i servizi resi disponibili dall'INPS»;
- b) al comma 2-bis) le parole da «secondo» fino alla fine del comma sono sostituite dalle seguenti: «secondo le modalita' e utilizzando i servizi resi disponibili dall'INPS»;
- c) i commi 2-ter) e 2-quater) sono abrogati.

9. Nei sessanta giorni successivi alla data di entrata in vigore del presente decreto, rimane in vigore l'obbligo per la lavoratrice di consegnare all'INPS il certificato medico di gravidanza indicante la data presunta del parto, nonche' la dichiarazione sostitutiva attestante la data del parto, ai sensi dell'articolo 21 del decreto legislativo n. 151 del 2001.

## Art. 62. - Disposizioni transitorie

1. Le disposizioni di cui ai commi 2 e 3-bis dell'articolo 3-bis del decreto legislativo n. 82 del 2005, come modificato dall'articolo 4 del presente decreto, producono effetti a partire dalla completa attuazione dell'ANPR e, comunque, non oltre il 31 dicembre 2017. Il decreto di cui all'articolo 4, comma 1, lettera e), e' adottato entro la stessa data.

2. Alla completa attuazione dell'ANPR, il Ministero dell'interno inserisce d'ufficio nell'ANPR i domicili digitali dei professionisti presenti nel Registro Ini-PEC che non abbiano ancora provveduto a indicarne uno nella predetta Anagrafe, fermo restando il diritto del professionista di modificare, in ogni momento, tale indicazione.

3. L'AgID definisce i limiti e le modalita' di applicazione dell'articolo 8-bis, comma 2, del decreto legislativo n. 82 del 2005, introdotto dall'articolo 9 del presente decreto entro centottanta giorni dall'entrata in vigore del presente decreto.

4. I certificati qualificati rilasciati prima dell'entrata in vigore del presente decreto a norma della direttiva 1999/93/CE, sono considerati certificati qualificati di firma elettronica a norma del regolamento eIDAS e dell'articolo 28 del decreto legislativo n. 82 del 2005, come modificato dall'articolo 24 del presente decreto, fino alla loro scadenza.

5. Il prestatore di servizi che ha presentato la relazione di conformita', ai sensi dell'articolo 51 del regolamento eIDAS, e' considerato prestatore di servizi fiduciari qualificato a norma del predetto regolamento e dell'articolo 29 del decreto legislativo n. 82 del 2005, come modificato dall'articolo 25 del presente decreto, fino al completamento della valutazione della relazione da parte dell'AgID.

6. Le Regioni e le Province autonome di Trento e Bolzano, di cui sono fatte salve le rispettive competenze e nel rispetto degli Statuti e delle relative norme di attuazione, favoriscono il raccordo dell'azione di riordino istituzionale degli enti territoriali, di cui alla legge 7 aprile 2014, n. 56, con le politiche digitali.

7. Entro novanta giorni dalla data di entrata in vigore del presente decreto, si procede all'adeguamento dello statuto dell'AgID alle modifiche introdotte al decreto legislativo n. 82 del 2005, come modificato dal presente decreto.

8. Per il periodo di cui all'articolo 63, comma 1, le regole tecniche di cui all'articolo 71, nonche' le regole tecniche e le linee guida dell'AgID sono adottate sentito il Commissario di cui allo stesso articolo 63, il quale puo' avvalersi dell'AgID per l'elaborazione delle regole tecniche dallo stesso adottate.

## Art. 63. - Nomina commissariale

1. Il Presidente del Consiglio dei ministri, in sede di prima attuazione del presente decreto, puo' nominare, per un periodo non superiore a tre anni, con proprio decreto, un Commissario straordinario per l'attuazione dell'Agenda digitale. Il Commissario svolge funzioni di coordinamento operativo dei soggetti pubblici, anche in forma societaria operanti nel settore delle tecnologie dell'informatica e della comunicazione e rilevanti per l'attuazione degli obiettivi di cui all'Agenda digitale italiana, limitatamente all'attuazione degli obiettivi di cui alla predetta Agenda digitale ed anche in coerenza con gli obiettivi dell'Agenda digitale europea.

2. Il Presidente del Consiglio dei ministri, con proprio decreto, individua uno o piu' progetti di rilevanza strategica e di interesse nazionale, dei quali puo' affidare l'attuazione, ai sensi del comma 1, al Commissario eventualmente nominato ai sensi del comma 1, autorizzandolo ad avvalersi anche dei soggetti di cui al comma 1.

3. Per la realizzazione delle azioni, iniziative ed opere essenziali, connesse e strumentali all'attuazione dell'Agenda digitale italiana, anche in coerenza con gli obiettivi dell'Agenda digitale europea, il Commissario esercita poteri di impulso e di coordinamento nei confronti delle pubbliche amministrazioni cui competono tali adempimenti, ivi inclusa l'Agenzia per l'Italia digitale, nonche' il potere sostitutivo secondo le modalita' di cui al comma 4.

4. In caso di inadempienze gestionali o amministrative relative all'attuazione delle misure necessarie ai fini del comma 3, il Commissario invita l'amministrazione competente ad adottare, entro il termine di trenta giorni dalla data della diffida, i provvedimenti dovuti; decorso inutilmente tale termine, il Commissario, su autorizzazione resa con decreto del Presidente del Consiglio, previa comunicazione al Consiglio dei ministri, esercita il potere sostitutivo.

5. Il Commissario, nell'ambito delle proprie competenze e limitatamente all'attuazione dell'Agenda digitale italiana, puo' avvalersi della collaborazione di societa' a partecipazione pubblica operanti nel settore delle tecnologie dell'informatica e della comunicazione, anche in relazione all'utilizzo delle relative risorse finalizzate allo scopo, e puo', inoltre, adottare nei confronti degli stessi soggetti e nei confronti delle pubbliche amministrazioni, regole tecniche e linee guida, nonche' richiedere dati, documenti e informazioni strumentali all'esercizio della propria attivita' e dei propri poteri.

6. Il Commissario rappresenta il Presidente del Consiglio nelle sedi istituzionali internazionali nelle quali si discute di innovazione tecnologica, agenda digitale europea e governance di Internet e partecipa, in ambito internazionale, agli incontri preparatori dei vertici istituzionali al fine di supportare il Presidente del Consiglio dei ministri nelle azioni strategiche in materia di innovazione tecnologica.

7. Con il decreto di cui al comma 1, sono altresi' definite la struttura di supporto e le modalita' operative, anche sul piano contabile, per la gestione dei progetti. Il Commissario operera' quale funzionario delegato in regime di contabilita' ordinaria, ai sensi del regio decreto 18 novembre 1923, n. 2440, e del decreto del Presidente della Repubblica 20 aprile 1994, n. 367, a valere per l'anno 2016 sulle risorse disponibili a legislazione vigente nel bilancio autonomo della Presidenza del Consiglio dei ministri.

8. Il Commissario straordinario riferisce al Presidente del Consiglio dei ministri sullo svolgimento della propria attivita'.

9. COMMA ABROGATO DAL D.L. 25 LUGLIO 2018, N. 91 CONVERTITO CON MODIFICAZIONI DALLA L. 21 SETTEMBRE 2018, N. 108. ((4))

--------------- AGGIORNAMENTO (4) Il D.L. 14 dicembre 2018, n. 135, convertito con modificazioni dalla L. 11 febbraio 2019, n. 12, ha disposto (con l'art. 8, comma 1-bis) che "Il mandato del Commissario straordinario per l'attuazione dell'Agenda digitale, nominato con decreto del Presidente del Consiglio dei ministri 25 ottobre 2018, ai sensi dell'articolo 63 del decreto legislativo 26 agosto 2016, n. 179, nonche' l'operativita' della relativa struttura di supporto, sono prorogati al 31 dicembre 2019". Ha inoltre disposto (con l'art. 8, comma 1-ter) che "A decorrere dal 1° gennaio 2020, al fine di garantire l'attuazione degli obiettivi dell'Agenda digitale italiana, anche in coerenza con l'Agenda digitale europea, le funzioni, i compiti e i poteri conferiti al Commissario straordinario per l'attuazione dell'Agenda digitale dall'articolo 63 del decreto legislativo 26 agosto 2016, n. 179, sono attribuiti al Presidente del Consiglio dei ministri o al Ministro delegato che li esercita per il tramite delle strutture della Presidenza del Consiglio dei ministri dallo stesso individuate, di concerto con il Ministero dell'economia e delle finanze per le materie di sua competenza".

## Art. 64. - Abrogazioni

1. Al decreto legislativo n. 82 del 2005 sono abrogati i seguenti articoli:

- a) 4;
- b) 10;
- c) 11;
- d) 19;
- e) 26;
- f) 27;
- g) 31;
- h) 50-bis;
- i) 55;
- j) 57-bis;
- k) 58;
- l) 67;
- m) 72;
- n) 74;
- o) 77;
- p) 78;
- q) 79;
- r) 80;
- s) 81;
- t) 82;
- u) 83; z) 84; aa) 85; bb) 86; cc) 87; dd) 88; ee) 89; ff) 92.

2. Al decreto legislativo 12 febbraio 1993, n. 39, gli articoli 1, 2, 3, comma 1, 10, 11, 12, 13, 14, 15, 16 e 18 sono abrogati.

3. Al decreto-legge 9 febbraio 2012, n. 5, i commi 2, 2-bis e 2-ter dell'articolo 47 sono abrogati.

4. Al decreto-legge 22 giugno 2012, n. 83, convertito, con modificazioni, dalla legge 7 agosto 2012, n. 134, sono apportate le seguenti modificazioni:

- a) l'articolo 20 e' abrogato;
- b) all'articolo 21, comma 4, le parole: «e dai membri del Tavolo permanente per l'innovazione e l'Agenda digitale italiana» sono sostituite dalle seguenti: «e dai rappresentanti delle amministrazioni centrali la cui spesa corrente di previsione per ciascun ministero in materia di informatica e digitalizzazione, assegnata dalle tabelle allegate alla legge annuale di stabilita', non sia inferiore al trenta per cento della previsione annuale complessiva per le Amministrazioni centrali, affinche' siano rappresentate sino alla concorrenza di almeno l'ottanta per cento della spesa corrente di previsione suindicata».

5. All'articolo 20 del decreto-legge 18 ottobre 2012, n. 179, convertito, con modificazioni, dalla legge 17 dicembre 2012, n. 221, sono apportate le seguenti modificazioni:

- a) all'articolo 20: 1) al comma 1: 1.1. le parole: «, sentito il comitato tecnico di cui al comma 2» sono soppresse; 1.2. le lettere a) e
- b) sono soppresse; 1.3. alla lettera c) le parole: «e procedurali nonche' di strumenti finanziari innovativi per lo sviluppo delle comunita' intelligenti» sono soppresse; 2) al comma 8, le parole: «delle iniziative del PNCI di cui al comma 1, lettera a)» sono sostituite da «degli obiettivi di cui al comma 1»; 3) al comma 9, le parole: «, sentito il Comitato di cui al comma 2,» sono soppresse; 4) i commi 2, 3, 5, 7, 10, 11, 12, 13, 14, 16, 17, e 19 sono abrogati.

6. All'articolo 24 del decreto-legge 24 giugno 2014, n. 90, convertito, con modificazioni, dalla legge 11 agosto 2014, n. 114, il comma 3-bis e' abrogato.

## Art. 65. - Clausola di invarianza finanziaria

1. All'attuazione delle disposizioni di cui al presente decreto si provvede nell'ambito delle risorse umane, strumentali e finanziarie disponibili a legislazione vigente e, comunque, senza nuovi o maggiori oneri per la finanza pubblica.

## Art. 66. - Entrata in vigore

1. Il presente decreto entra in vigore il giorno successivo alla pubblicazione nella Gazzetta Ufficiale della Repubblica italiana.

